# Other

## `reflow.signals.TaskInterrupted`

::: reflow.signals.TaskInterrupted
    options:
      show_source: true

## `reflow.signals.graceful_shutdown`

::: reflow.signals.graceful_shutdown
    options:
      show_source: true

## `reflow.config.Config`

::: reflow.config.Config
    options:
      show_source: true

## `reflow.manifest.ManifestCodec`

::: reflow.manifest.ManifestCodec
    options:
      show_source: true

## `reflow._types.TaskState`

::: reflow._types.TaskState
    options:
      show_source: true

## `reflow._types.RunState`

::: reflow._types.RunState
    options:
      show_source: true
